summaryrefslogtreecommitdiffstats
path: root/cpukit/score/include/rtems/score/coremsg.h
diff options
context:
space:
mode:
authorRalf Corsepius <ralf.corsepius@rtems.org>2004-03-29 16:41:13 +0000
committerRalf Corsepius <ralf.corsepius@rtems.org>2004-03-29 16:41:13 +0000
commitd6154c70dc048e21aae907fd053a1e7a1d155408 (patch)
tree9ecb1475f4432a19f423da0ff73fbec9a87536af /cpukit/score/include/rtems/score/coremsg.h
parent2004-03-29 Ralf Corsepius <ralf_corsepius@rtems.org> (diff)
downloadrtems-d6154c70dc048e21aae907fd053a1e7a1d155408.tar.bz2
2004-03-29 Ralf Corsepius <ralf_corsepius@rtems.org>
* score/include/rtems/debug.h, score/include/rtems/score/bitfield.h, score/include/rtems/score/chain.h, score/include/rtems/score/coremsg.h, score/include/rtems/score/coremutex.h, score/include/rtems/score/coresem.h, score/include/rtems/score/heap.h, score/include/rtems/score/interr.h, score/include/rtems/score/isr.h, score/include/rtems/score/mpci.h, score/include/rtems/score/mppkt.h, score/include/rtems/score/object.h, score/include/rtems/score/objectmp.h, score/include/rtems/score/priority.h, score/include/rtems/score/stack.h, score/include/rtems/score/states.h, score/include/rtems/score/thread.h, score/include/rtems/score/threadmp.h, score/include/rtems/score/threadq.h, score/include/rtems/score/tod.h, score/include/rtems/score/tqdata.h, score/include/rtems/score/userext.h, score/include/rtems/score/watchdog.h, score/include/rtems/score/wkspace.h, score/inline/rtems/score/address.inl, score/inline/rtems/score/coremsg.inl, score/inline/rtems/score/coresem.inl, score/inline/rtems/score/heap.inl, score/inline/rtems/score/isr.inl, score/inline/rtems/score/object.inl, score/inline/rtems/score/priority.inl, score/inline/rtems/score/stack.inl, score/inline/rtems/score/thread.inl, score/inline/rtems/score/tqdata.inl, score/inline/rtems/score/userext.inl, score/inline/rtems/score/wkspace.inl, score/macros/rtems/score/address.inl, score/macros/rtems/score/heap.inl, score/macros/rtems/score/object.inl, score/macros/rtems/score/priority.inl, score/macros/rtems/score/userext.inl: Convert to using c99 fixed size types.
Diffstat (limited to 'cpukit/score/include/rtems/score/coremsg.h')
-rw-r--r--cpukit/score/include/rtems/score/coremsg.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/cpukit/score/include/rtems/score/coremsg.h b/cpukit/score/include/rtems/score/coremsg.h
index 9b1d3025d2..b1a65ba7b1 100644
--- a/cpukit/score/include/rtems/score/coremsg.h
+++ b/cpukit/score/include/rtems/score/coremsg.h
@@ -40,13 +40,13 @@ typedef void ( *CORE_message_queue_API_mp_support_callout )(
* The following defines the data types needed to manipulate
* the contents of message buffers.
*
* NOTE: The buffer field is normally longer than a single unsigned32.
* but since messages are variable length we just make a ptr to 1.
*/
typedef struct {
- unsigned32 size;
- unsigned32 buffer[1];
+ uint32_t size;
+ uint32_t buffer[1];
} CORE_message_queue_Buffer;
/*
@@ -124,9 +124,9 @@ typedef void (*CORE_message_queue_Notify_Handler)( void * );
typedef struct {
Thread_queue_Control Wait_queue;
CORE_message_queue_Attributes Attributes;
- unsigned32 maximum_pending_messages;
- unsigned32 number_of_pending_messages;
- unsigned32 maximum_message_size;
+ uint32_t maximum_pending_messages;
+ uint32_t number_of_pending_messages;
+ uint32_t maximum_message_size;
Chain_Control Pending_messages;
CORE_message_queue_Buffer *message_buffers;
CORE_message_queue_Notify_Handler notify_handler;
@@ -145,8 +145,8 @@ typedef struct {
boolean _CORE_message_queue_Initialize(
CORE_message_queue_Control *the_message_queue,
CORE_message_queue_Attributes *the_message_queue_attributes,
- unsigned32 maximum_pending_messages,
- unsigned32 maximum_message_size
+ uint32_t maximum_pending_messages,
+ uint32_t maximum_message_size
);
/*
@@ -161,7 +161,7 @@ boolean _CORE_message_queue_Initialize(
void _CORE_message_queue_Close(
CORE_message_queue_Control *the_message_queue,
Thread_queue_Flush_callout remote_extract_callout,
- unsigned32 status
+ uint32_t status
);
/*
@@ -174,7 +174,7 @@ void _CORE_message_queue_Close(
*
*/
-unsigned32 _CORE_message_queue_Flush(
+uint32_t _CORE_message_queue_Flush(
CORE_message_queue_Control *the_message_queue
);
@@ -187,7 +187,7 @@ unsigned32 _CORE_message_queue_Flush(
* them to the inactive message chain.
*/
-unsigned32 _CORE_message_queue_Flush_support(
+uint32_t _CORE_message_queue_Flush_support(
CORE_message_queue_Control *the_message_queue
);
@@ -218,10 +218,10 @@ void _CORE_message_queue_Flush_waiting_threads(
CORE_message_queue_Status _CORE_message_queue_Broadcast(
CORE_message_queue_Control *the_message_queue,
void *buffer,
- unsigned32 size,
+ uint32_t size,
Objects_Id id,
CORE_message_queue_API_mp_support_callout api_message_queue_mp_support,
- unsigned32 *count
+ uint32_t *count
);
/*
@@ -241,7 +241,7 @@ CORE_message_queue_Status _CORE_message_queue_Broadcast(
CORE_message_queue_Status _CORE_message_queue_Submit(
CORE_message_queue_Control *the_message_queue,
void *buffer,
- unsigned32 size,
+ uint32_t size,
Objects_Id id,
CORE_message_queue_API_mp_support_callout api_message_queue_mp_support,
CORE_message_queue_Submit_types submit_type,
@@ -266,7 +266,7 @@ void _CORE_message_queue_Seize(
CORE_message_queue_Control *the_message_queue,
Objects_Id id,
void *buffer,
- unsigned32 *size,
+ uint32_t *size,
boolean wait,
Watchdog_Interval timeout
);
@@ -40,13 +40,13 @@ typedef void ( *CORE_message_queue_API_mp_support_callout )(
* the contents of message buffers.
*
- * NOTE: The buffer field is normally longer than a single unsigned32.
+ * NOTE: The buffer field is normally longer than a single uint32_t .
* but since messages are variable length we just make a ptr to 1.
*/